# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[builtins.str],
                 pai_task_enabled: pulumi.Input[builtins.bool],
                 project_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dev_environment_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dev_role_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[builtins.str] display_name: Workspace Display Name
        :param pulumi.Input[builtins.bool] pai_task_enabled: Create PAI Workspace Together
        :param pulumi.Input[builtins.str] project_name: Workspace Name
        :param pulumi.Input[builtins.str] description: Workspace Description
        :param pulumi.Input[builtins.bool] dev_environment_enabled: Is Development Environment Enabled
        :param pulumi.Input[builtins.bool] dev_role_disabled: Is Development Role Disabled
        :param pulumi.Input[builtins.str] resource_group_id: Aliyun Resource Group Id
        :param pulumi.Input[builtins.str] status: Workspace Status
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Aliyun Resource Tag
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "pai_task_enabled", pai_task_enabled)
        pulumi.set(__self__, "project_name", project_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dev_environment_enabled is not None:
            pulumi.set(__self__, "dev_environment_enabled", dev_environment_enabled)
        if dev_role_disabled is not None:
            pulumi.set(__self__, "dev_role_disabled", dev_role_disabled)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[builtins.str]:
        """
        Workspace Display Name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="paiTaskEnabled")
    def pai_task_enabled(self) -> pulumi.Input[builtins.bool]:
        """
        Create PAI Workspace Together
        """
        return pulumi.get(self, "pai_task_enabled")

    @pai_task_enabled.setter
    def pai_task_enabled(self, value: pulumi.Input[builtins.bool]):
        pulumi.set(self, "pai_task_enabled", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[builtins.str]:
        """
        Workspace Name
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="devEnvironmentEnabled")
    def dev_environment_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is Development Environment Enabled
        """
        return pulumi.get(self, "dev_environment_enabled")

    @dev_environment_enabled.setter
    def dev_environment_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dev_environment_enabled", value)

    @property
    @pulumi.getter(name="devRoleDisabled")
    def dev_role_disabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is Development Role Disabled
        """
        return pulumi.get(self, "dev_role_disabled")

    @dev_role_disabled.setter
    def dev_role_disabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dev_role_disabled", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Aliyun Resource Group Id
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Aliyun Resource Tag
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dev_environment_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dev_role_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 pai_task_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[builtins.str] description: Workspace Description
        :param pulumi.Input[builtins.bool] dev_environment_enabled: Is Development Environment Enabled
        :param pulumi.Input[builtins.bool] dev_role_disabled: Is Development Role Disabled
        :param pulumi.Input[builtins.str] display_name: Workspace Display Name
        :param pulumi.Input[builtins.bool] pai_task_enabled: Create PAI Workspace Together
        :param pulumi.Input[builtins.str] project_name: Workspace Name
        :param pulumi.Input[builtins.str] resource_group_id: Aliyun Resource Group Id
        :param pulumi.Input[builtins.str] status: Workspace Status
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Aliyun Resource Tag
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dev_environment_enabled is not None:
            pulumi.set(__self__, "dev_environment_enabled", dev_environment_enabled)
        if dev_role_disabled is not None:
            pulumi.set(__self__, "dev_role_disabled", dev_role_disabled)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if pai_task_enabled is not None:
            pulumi.set(__self__, "pai_task_enabled", pai_task_enabled)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="devEnvironmentEnabled")
    def dev_environment_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is Development Environment Enabled
        """
        return pulumi.get(self, "dev_environment_enabled")

    @dev_environment_enabled.setter
    def dev_environment_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dev_environment_enabled", value)

    @property
    @pulumi.getter(name="devRoleDisabled")
    def dev_role_disabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is Development Role Disabled
        """
        return pulumi.get(self, "dev_role_disabled")

    @dev_role_disabled.setter
    def dev_role_disabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dev_role_disabled", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace Display Name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="paiTaskEnabled")
    def pai_task_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Create PAI Workspace Together
        """
        return pulumi.get(self, "pai_task_enabled")

    @pai_task_enabled.setter
    def pai_task_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "pai_task_enabled", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace Name
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Aliyun Resource Group Id
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Workspace Status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Aliyun Resource Tag
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("alicloud:dataworks/project:Project")
class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dev_environment_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dev_role_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 pai_task_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a Data Works Project resource.

        For information about Data Works Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createproject).

        > **NOTE:** Available since v1.229.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        randint = random.index.Integer("randint",
            max=999,
            min=1)
        default = alicloud.resourcemanager.get_resource_groups()
        default_project = alicloud.dataworks.Project("default",
            status="Available",
            description="tf_desc",
            project_name=f"{name}{randint['id']}",
            pai_task_enabled=False,
            display_name="tf_new_api_display",
            dev_role_disabled=True,
            dev_environment_enabled=False,
            resource_group_id=default.ids[0])
        ```

        ## Import

        Data Works Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/project:Project example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Workspace Description
        :param pulumi.Input[builtins.bool] dev_environment_enabled: Is Development Environment Enabled
        :param pulumi.Input[builtins.bool] dev_role_disabled: Is Development Role Disabled
        :param pulumi.Input[builtins.str] display_name: Workspace Display Name
        :param pulumi.Input[builtins.bool] pai_task_enabled: Create PAI Workspace Together
        :param pulumi.Input[builtins.str] project_name: Workspace Name
        :param pulumi.Input[builtins.str] resource_group_id: Aliyun Resource Group Id
        :param pulumi.Input[builtins.str] status: Workspace Status
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Aliyun Resource Tag
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Project resource.

        For information about Data Works Project and how to use it, see [What is Project](https://www.alibabacloud.com/help/en/dataworks/developer-reference/api-dataworks-public-2024-05-18-createproject).

        > **NOTE:** Available since v1.229.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf_example"
        randint = random.index.Integer("randint",
            max=999,
            min=1)
        default = alicloud.resourcemanager.get_resource_groups()
        default_project = alicloud.dataworks.Project("default",
            status="Available",
            description="tf_desc",
            project_name=f"{name}{randint['id']}",
            pai_task_enabled=False,
            display_name="tf_new_api_display",
            dev_role_disabled=True,
            dev_environment_enabled=False,
            resource_group_id=default.ids[0])
        ```

        ## Import

        Data Works Project can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/project:Project example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 dev_environment_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 dev_role_disabled: Optional[pulumi.Input[builtins.bool]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 pai_task_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["dev_environment_enabled"] = dev_environment_enabled
            __props__.__dict__["dev_role_disabled"] = dev_role_disabled
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if pai_task_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'pai_task_enabled'")
            __props__.__dict__["pai_task_enabled"] = pai_task_enabled
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["resource_group_id"] = resource_group_id
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
        super(Project, __self__).__init__(
            'alicloud:dataworks/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            dev_environment_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            dev_role_disabled: Optional[pulumi.Input[builtins.bool]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            pai_task_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Workspace Description
        :param pulumi.Input[builtins.bool] dev_environment_enabled: Is Development Environment Enabled
        :param pulumi.Input[builtins.bool] dev_role_disabled: Is Development Role Disabled
        :param pulumi.Input[builtins.str] display_name: Workspace Display Name
        :param pulumi.Input[builtins.bool] pai_task_enabled: Create PAI Workspace Together
        :param pulumi.Input[builtins.str] project_name: Workspace Name
        :param pulumi.Input[builtins.str] resource_group_id: Aliyun Resource Group Id
        :param pulumi.Input[builtins.str] status: Workspace Status
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Aliyun Resource Tag
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["description"] = description
        __props__.__dict__["dev_environment_enabled"] = dev_environment_enabled
        __props__.__dict__["dev_role_disabled"] = dev_role_disabled
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["pai_task_enabled"] = pai_task_enabled
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Workspace Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="devEnvironmentEnabled")
    def dev_environment_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Is Development Environment Enabled
        """
        return pulumi.get(self, "dev_environment_enabled")

    @property
    @pulumi.getter(name="devRoleDisabled")
    def dev_role_disabled(self) -> pulumi.Output[builtins.bool]:
        """
        Is Development Role Disabled
        """
        return pulumi.get(self, "dev_role_disabled")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Workspace Display Name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="paiTaskEnabled")
    def pai_task_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Create PAI Workspace Together
        """
        return pulumi.get(self, "pai_task_enabled")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        Workspace Name
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[builtins.str]:
        """
        Aliyun Resource Group Id
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Workspace Status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Aliyun Resource Tag
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccountArgs', 'Account']

@pulumi.input_type
class AccountArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[builtins.str],
                 abandon_able_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 abandonable_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 account_name_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[builtins.bool]] = None,
                 payer_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 resell_account_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Account resource.
        :param pulumi.Input[builtins.str] display_name: Member name
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandon_able_check_ids: . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandonable_check_ids: The ID of the check item that can choose to abandon and continue to perform member deletion.
               The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        :param pulumi.Input[builtins.str] account_name_prefix: Account name prefix. Empty the system randomly generated.
               Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
               The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
               The account name must be unique in the resource directory.
        :param pulumi.Input[builtins.str] folder_id: The ID of the parent folder
        :param pulumi.Input[builtins.bool] force_delete: Whether to force delete the account.
        :param pulumi.Input[builtins.str] payer_account_id: The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        :param pulumi.Input[builtins.str] resell_account_type: The identity type of the member. Valid values:
               - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
               - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.
               
               > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] type: Member type. The value of ResourceAccount indicates the resource account
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        pulumi.set(__self__, "display_name", display_name)
        if abandon_able_check_ids is not None:
            warnings.warn("""Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""abandon_able_check_ids is deprecated: Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""")
        if abandon_able_check_ids is not None:
            pulumi.set(__self__, "abandon_able_check_ids", abandon_able_check_ids)
        if abandonable_check_ids is not None:
            pulumi.set(__self__, "abandonable_check_ids", abandonable_check_ids)
        if account_name_prefix is not None:
            pulumi.set(__self__, "account_name_prefix", account_name_prefix)
        if folder_id is not None:
            pulumi.set(__self__, "folder_id", folder_id)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if payer_account_id is not None:
            pulumi.set(__self__, "payer_account_id", payer_account_id)
        if resell_account_type is not None:
            pulumi.set(__self__, "resell_account_type", resell_account_type)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[builtins.str]:
        """
        Member name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="abandonAbleCheckIds")
    @_utilities.deprecated("""Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""")
    def abandon_able_check_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        """
        return pulumi.get(self, "abandon_able_check_ids")

    @abandon_able_check_ids.setter
    def abandon_able_check_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "abandon_able_check_ids", value)

    @property
    @pulumi.getter(name="abandonableCheckIds")
    def abandonable_check_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The ID of the check item that can choose to abandon and continue to perform member deletion.
        The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        """
        return pulumi.get(self, "abandonable_check_ids")

    @abandonable_check_ids.setter
    def abandonable_check_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "abandonable_check_ids", value)

    @property
    @pulumi.getter(name="accountNamePrefix")
    def account_name_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Account name prefix. Empty the system randomly generated.
        Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
        The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
        The account name must be unique in the resource directory.
        """
        return pulumi.get(self, "account_name_prefix")

    @account_name_prefix.setter
    def account_name_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name_prefix", value)

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the parent folder
        """
        return pulumi.get(self, "folder_id")

    @folder_id.setter
    def folder_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "folder_id", value)

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to force delete the account.
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @property
    @pulumi.getter(name="payerAccountId")
    def payer_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        """
        return pulumi.get(self, "payer_account_id")

    @payer_account_id.setter
    def payer_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payer_account_id", value)

    @property
    @pulumi.getter(name="resellAccountType")
    def resell_account_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identity type of the member. Valid values:
        - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
        - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.

        > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        """
        return pulumi.get(self, "resell_account_type")

    @resell_account_type.setter
    def resell_account_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resell_account_type", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Member type. The value of ResourceAccount indicates the resource account

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _AccountState:
    def __init__(__self__, *,
                 abandon_able_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 abandonable_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 account_name_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[builtins.bool]] = None,
                 join_method: Optional[pulumi.Input[builtins.str]] = None,
                 join_time: Optional[pulumi.Input[builtins.str]] = None,
                 modify_time: Optional[pulumi.Input[builtins.str]] = None,
                 payer_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 resell_account_type: Optional[pulumi.Input[builtins.str]] = None,
                 resource_directory_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Account resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandon_able_check_ids: . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandonable_check_ids: The ID of the check item that can choose to abandon and continue to perform member deletion.
               The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        :param pulumi.Input[builtins.str] account_name_prefix: Account name prefix. Empty the system randomly generated.
               Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
               The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
               The account name must be unique in the resource directory.
        :param pulumi.Input[builtins.str] display_name: Member name
        :param pulumi.Input[builtins.str] folder_id: The ID of the parent folder
        :param pulumi.Input[builtins.bool] force_delete: Whether to force delete the account.
        :param pulumi.Input[builtins.str] join_method: Ways for members to join the resource directory.  invited, created
        :param pulumi.Input[builtins.str] join_time: The time when the member joined the resource directory
        :param pulumi.Input[builtins.str] modify_time: The modification time of the invitation
        :param pulumi.Input[builtins.str] payer_account_id: The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        :param pulumi.Input[builtins.str] resell_account_type: The identity type of the member. Valid values:
               - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
               - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.
               
               > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        :param pulumi.Input[builtins.str] resource_directory_id: Resource directory ID
        :param pulumi.Input[builtins.str] status: Member joining status.  CreateSuccess,CreateVerifying,CreateFailed,CreateExpired,CreateCancelled,PromoteVerifying,PromoteFailed,PromoteExpired,PromoteCancelled,PromoteSuccess,InviteSuccess,Removed
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] type: Member type. The value of ResourceAccount indicates the resource account
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        if abandon_able_check_ids is not None:
            warnings.warn("""Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""", DeprecationWarning)
            pulumi.log.warn("""abandon_able_check_ids is deprecated: Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""")
        if abandon_able_check_ids is not None:
            pulumi.set(__self__, "abandon_able_check_ids", abandon_able_check_ids)
        if abandonable_check_ids is not None:
            pulumi.set(__self__, "abandonable_check_ids", abandonable_check_ids)
        if account_name_prefix is not None:
            pulumi.set(__self__, "account_name_prefix", account_name_prefix)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if folder_id is not None:
            pulumi.set(__self__, "folder_id", folder_id)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if join_method is not None:
            pulumi.set(__self__, "join_method", join_method)
        if join_time is not None:
            pulumi.set(__self__, "join_time", join_time)
        if modify_time is not None:
            pulumi.set(__self__, "modify_time", modify_time)
        if payer_account_id is not None:
            pulumi.set(__self__, "payer_account_id", payer_account_id)
        if resell_account_type is not None:
            pulumi.set(__self__, "resell_account_type", resell_account_type)
        if resource_directory_id is not None:
            pulumi.set(__self__, "resource_directory_id", resource_directory_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="abandonAbleCheckIds")
    @_utilities.deprecated("""Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""")
    def abandon_able_check_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        """
        return pulumi.get(self, "abandon_able_check_ids")

    @abandon_able_check_ids.setter
    def abandon_able_check_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "abandon_able_check_ids", value)

    @property
    @pulumi.getter(name="abandonableCheckIds")
    def abandonable_check_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The ID of the check item that can choose to abandon and continue to perform member deletion.
        The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        """
        return pulumi.get(self, "abandonable_check_ids")

    @abandonable_check_ids.setter
    def abandonable_check_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "abandonable_check_ids", value)

    @property
    @pulumi.getter(name="accountNamePrefix")
    def account_name_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Account name prefix. Empty the system randomly generated.
        Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
        The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
        The account name must be unique in the resource directory.
        """
        return pulumi.get(self, "account_name_prefix")

    @account_name_prefix.setter
    def account_name_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name_prefix", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Member name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the parent folder
        """
        return pulumi.get(self, "folder_id")

    @folder_id.setter
    def folder_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "folder_id", value)

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to force delete the account.
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @property
    @pulumi.getter(name="joinMethod")
    def join_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ways for members to join the resource directory.  invited, created
        """
        return pulumi.get(self, "join_method")

    @join_method.setter
    def join_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "join_method", value)

    @property
    @pulumi.getter(name="joinTime")
    def join_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the member joined the resource directory
        """
        return pulumi.get(self, "join_time")

    @join_time.setter
    def join_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "join_time", value)

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The modification time of the invitation
        """
        return pulumi.get(self, "modify_time")

    @modify_time.setter
    def modify_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_time", value)

    @property
    @pulumi.getter(name="payerAccountId")
    def payer_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        """
        return pulumi.get(self, "payer_account_id")

    @payer_account_id.setter
    def payer_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "payer_account_id", value)

    @property
    @pulumi.getter(name="resellAccountType")
    def resell_account_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The identity type of the member. Valid values:
        - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
        - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.

        > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        """
        return pulumi.get(self, "resell_account_type")

    @resell_account_type.setter
    def resell_account_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resell_account_type", value)

    @property
    @pulumi.getter(name="resourceDirectoryId")
    def resource_directory_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource directory ID
        """
        return pulumi.get(self, "resource_directory_id")

    @resource_directory_id.setter
    def resource_directory_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_directory_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Member joining status.  CreateSuccess,CreateVerifying,CreateFailed,CreateExpired,CreateCancelled,PromoteVerifying,PromoteFailed,PromoteExpired,PromoteCancelled,PromoteSuccess,InviteSuccess,Removed
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Member type. The value of ResourceAccount indicates the resource account

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("alicloud:resourcemanager/account:Account")
class Account(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 abandon_able_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 abandonable_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 account_name_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[builtins.bool]] = None,
                 payer_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 resell_account_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Resource Manager Account resource.

        For information about Resource Manager Account and how to use it, see [What is Account](https://www.alibabacloud.com/help/en/doc-detail/111231.htm).

        > **NOTE:** Available since v1.83.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        display_name = config.get("displayName")
        if display_name is None:
            display_name = "EAccount"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        example = alicloud.resourcemanager.get_folders()
        example_account = alicloud.resourcemanager.Account("example",
            display_name=f"{display_name}-{default['result']}",
            folder_id=example.ids[0])
        ```

        ## Import

        Resource Manager Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/account:Account example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandon_able_check_ids: . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandonable_check_ids: The ID of the check item that can choose to abandon and continue to perform member deletion.
               The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        :param pulumi.Input[builtins.str] account_name_prefix: Account name prefix. Empty the system randomly generated.
               Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
               The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
               The account name must be unique in the resource directory.
        :param pulumi.Input[builtins.str] display_name: Member name
        :param pulumi.Input[builtins.str] folder_id: The ID of the parent folder
        :param pulumi.Input[builtins.bool] force_delete: Whether to force delete the account.
        :param pulumi.Input[builtins.str] payer_account_id: The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        :param pulumi.Input[builtins.str] resell_account_type: The identity type of the member. Valid values:
               - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
               - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.
               
               > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] type: Member type. The value of ResourceAccount indicates the resource account
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Resource Manager Account resource.

        For information about Resource Manager Account and how to use it, see [What is Account](https://www.alibabacloud.com/help/en/doc-detail/111231.htm).

        > **NOTE:** Available since v1.83.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        display_name = config.get("displayName")
        if display_name is None:
            display_name = "EAccount"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        example = alicloud.resourcemanager.get_folders()
        example_account = alicloud.resourcemanager.Account("example",
            display_name=f"{display_name}-{default['result']}",
            folder_id=example.ids[0])
        ```

        ## Import

        Resource Manager Account can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/account:Account example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 abandon_able_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 abandonable_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 account_name_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[builtins.bool]] = None,
                 payer_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 resell_account_type: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountArgs.__new__(AccountArgs)

            __props__.__dict__["abandon_able_check_ids"] = abandon_able_check_ids
            __props__.__dict__["abandonable_check_ids"] = abandonable_check_ids
            __props__.__dict__["account_name_prefix"] = account_name_prefix
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["folder_id"] = folder_id
            __props__.__dict__["force_delete"] = force_delete
            __props__.__dict__["payer_account_id"] = payer_account_id
            __props__.__dict__["resell_account_type"] = resell_account_type
            __props__.__dict__["tags"] = tags
            __props__.__dict__["type"] = type
            __props__.__dict__["join_method"] = None
            __props__.__dict__["join_time"] = None
            __props__.__dict__["modify_time"] = None
            __props__.__dict__["resource_directory_id"] = None
            __props__.__dict__["status"] = None
        super(Account, __self__).__init__(
            'alicloud:resourcemanager/account:Account',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            abandon_able_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            abandonable_check_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            account_name_prefix: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            folder_id: Optional[pulumi.Input[builtins.str]] = None,
            force_delete: Optional[pulumi.Input[builtins.bool]] = None,
            join_method: Optional[pulumi.Input[builtins.str]] = None,
            join_time: Optional[pulumi.Input[builtins.str]] = None,
            modify_time: Optional[pulumi.Input[builtins.str]] = None,
            payer_account_id: Optional[pulumi.Input[builtins.str]] = None,
            resell_account_type: Optional[pulumi.Input[builtins.str]] = None,
            resource_directory_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None) -> 'Account':
        """
        Get an existing Account resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandon_able_check_ids: . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] abandonable_check_ids: The ID of the check item that can choose to abandon and continue to perform member deletion.
               The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        :param pulumi.Input[builtins.str] account_name_prefix: Account name prefix. Empty the system randomly generated.
               Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
               The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
               The account name must be unique in the resource directory.
        :param pulumi.Input[builtins.str] display_name: Member name
        :param pulumi.Input[builtins.str] folder_id: The ID of the parent folder
        :param pulumi.Input[builtins.bool] force_delete: Whether to force delete the account.
        :param pulumi.Input[builtins.str] join_method: Ways for members to join the resource directory.  invited, created
        :param pulumi.Input[builtins.str] join_time: The time when the member joined the resource directory
        :param pulumi.Input[builtins.str] modify_time: The modification time of the invitation
        :param pulumi.Input[builtins.str] payer_account_id: The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        :param pulumi.Input[builtins.str] resell_account_type: The identity type of the member. Valid values:
               - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
               - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.
               
               > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        :param pulumi.Input[builtins.str] resource_directory_id: Resource directory ID
        :param pulumi.Input[builtins.str] status: Member joining status.  CreateSuccess,CreateVerifying,CreateFailed,CreateExpired,CreateCancelled,PromoteVerifying,PromoteFailed,PromoteExpired,PromoteCancelled,PromoteSuccess,InviteSuccess,Removed
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The tag of the resource
        :param pulumi.Input[builtins.str] type: Member type. The value of ResourceAccount indicates the resource account
               
               The following arguments will be discarded. Please use new fields as soon as possible:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountState.__new__(_AccountState)

        __props__.__dict__["abandon_able_check_ids"] = abandon_able_check_ids
        __props__.__dict__["abandonable_check_ids"] = abandonable_check_ids
        __props__.__dict__["account_name_prefix"] = account_name_prefix
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["folder_id"] = folder_id
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["join_method"] = join_method
        __props__.__dict__["join_time"] = join_time
        __props__.__dict__["modify_time"] = modify_time
        __props__.__dict__["payer_account_id"] = payer_account_id
        __props__.__dict__["resell_account_type"] = resell_account_type
        __props__.__dict__["resource_directory_id"] = resource_directory_id
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        return Account(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="abandonAbleCheckIds")
    @_utilities.deprecated("""Field 'abandon_able_check_id' has been deprecated since provider version 1.248.0. New field 'abandonable_check_id' instead.""")
    def abandon_able_check_ids(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        . Field 'abandon_able_check_id' has been deprecated from provider version 1.249.0. New field 'abandonable_check_id' instead.
        """
        return pulumi.get(self, "abandon_able_check_ids")

    @property
    @pulumi.getter(name="abandonableCheckIds")
    def abandonable_check_ids(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        The ID of the check item that can choose to abandon and continue to perform member deletion.
        The ID is obtained from the return parameter AbandonableChecks of GetAccountDeletionCheckResult.
        """
        return pulumi.get(self, "abandonable_check_ids")

    @property
    @pulumi.getter(name="accountNamePrefix")
    def account_name_prefix(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Account name prefix. Empty the system randomly generated.
        Format: English letters, numbers, and special characters_.-can be entered. It must start and end with an English letter or number, and continuous special characters_.-cannot be entered '_.-'.
        The format of the full account name is @< ResourceDirectoryId>.aliyunid.com, for example: 'alice @ rd-3G ****.aliyunid.com'
        The account name must be unique in the resource directory.
        """
        return pulumi.get(self, "account_name_prefix")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        Member name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the parent folder
        """
        return pulumi.get(self, "folder_id")

    @property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether to force delete the account.
        """
        return pulumi.get(self, "force_delete")

    @property
    @pulumi.getter(name="joinMethod")
    def join_method(self) -> pulumi.Output[builtins.str]:
        """
        Ways for members to join the resource directory.  invited, created
        """
        return pulumi.get(self, "join_method")

    @property
    @pulumi.getter(name="joinTime")
    def join_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the member joined the resource directory
        """
        return pulumi.get(self, "join_time")

    @property
    @pulumi.getter(name="modifyTime")
    def modify_time(self) -> pulumi.Output[builtins.str]:
        """
        The modification time of the invitation
        """
        return pulumi.get(self, "modify_time")

    @property
    @pulumi.getter(name="payerAccountId")
    def payer_account_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The settlement account ID. If it is left blank, the newly created member will be used for self-settlement.
        """
        return pulumi.get(self, "payer_account_id")

    @property
    @pulumi.getter(name="resellAccountType")
    def resell_account_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The identity type of the member. Valid values:
        - resell: The member is an account for a reseller. This is the default value. A relationship is automatically established between the member and the reseller. The management account of the resource directory must be used as the billing account of the member.
        - non_resell: The member is not an account for a reseller. The member is an account that is not associated with a reseller. You can directly use the account to purchase Alibaba Cloud resources. The member is used as its own billing account.

        > **NOTE:**  This parameter is available only for resellers at the international site (alibabacloud.com).
        """
        return pulumi.get(self, "resell_account_type")

    @property
    @pulumi.getter(name="resourceDirectoryId")
    def resource_directory_id(self) -> pulumi.Output[builtins.str]:
        """
        Resource directory ID
        """
        return pulumi.get(self, "resource_directory_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Member joining status.  CreateSuccess,CreateVerifying,CreateFailed,CreateExpired,CreateCancelled,PromoteVerifying,PromoteFailed,PromoteExpired,PromoteCancelled,PromoteSuccess,InviteSuccess,Removed
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The tag of the resource
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Member type. The value of ResourceAccount indicates the resource account

        The following arguments will be discarded. Please use new fields as soon as possible:
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DbProxyPublicArgs', 'DbProxyPublic']

@pulumi.input_type
class DbProxyPublicArgs:
    def __init__(__self__, *,
                 connection_string_prefix: pulumi.Input[builtins.str],
                 db_instance_id: pulumi.Input[builtins.str],
                 db_proxy_connection_string_net_type: pulumi.Input[builtins.str],
                 db_proxy_endpoint_id: pulumi.Input[builtins.str],
                 db_proxy_new_connect_string_port: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a DbProxyPublic resource.
        :param pulumi.Input[builtins.str] connection_string_prefix: The prefix for the new database proxy connection address can be customized.
        :param pulumi.Input[builtins.str] db_instance_id: Instance ID.
        :param pulumi.Input[builtins.str] db_proxy_connection_string_net_type: The network type of the new database proxy connection address,This resource defaults to Public.
        :param pulumi.Input[builtins.str] db_proxy_endpoint_id: Database proxy connection address ID.
        :param pulumi.Input[builtins.str] db_proxy_new_connect_string_port: The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        pulumi.set(__self__, "connection_string_prefix", connection_string_prefix)
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        pulumi.set(__self__, "db_proxy_connection_string_net_type", db_proxy_connection_string_net_type)
        pulumi.set(__self__, "db_proxy_endpoint_id", db_proxy_endpoint_id)
        if db_proxy_new_connect_string_port is not None:
            pulumi.set(__self__, "db_proxy_new_connect_string_port", db_proxy_new_connect_string_port)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> pulumi.Input[builtins.str]:
        """
        The prefix for the new database proxy connection address can be customized.
        """
        return pulumi.get(self, "connection_string_prefix")

    @connection_string_prefix.setter
    def connection_string_prefix(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "connection_string_prefix", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Input[builtins.str]:
        """
        Instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="dbProxyConnectionStringNetType")
    def db_proxy_connection_string_net_type(self) -> pulumi.Input[builtins.str]:
        """
        The network type of the new database proxy connection address,This resource defaults to Public.
        """
        return pulumi.get(self, "db_proxy_connection_string_net_type")

    @db_proxy_connection_string_net_type.setter
    def db_proxy_connection_string_net_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "db_proxy_connection_string_net_type", value)

    @property
    @pulumi.getter(name="dbProxyEndpointId")
    def db_proxy_endpoint_id(self) -> pulumi.Input[builtins.str]:
        """
        Database proxy connection address ID.
        """
        return pulumi.get(self, "db_proxy_endpoint_id")

    @db_proxy_endpoint_id.setter
    def db_proxy_endpoint_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "db_proxy_endpoint_id", value)

    @property
    @pulumi.getter(name="dbProxyNewConnectStringPort")
    def db_proxy_new_connect_string_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        return pulumi.get(self, "db_proxy_new_connect_string_port")

    @db_proxy_new_connect_string_port.setter
    def db_proxy_new_connect_string_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_proxy_new_connect_string_port", value)


@pulumi.input_type
class _DbProxyPublicState:
    def __init__(__self__, *,
                 connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_connection_string_net_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_new_connect_string_port: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering DbProxyPublic resources.
        :param pulumi.Input[builtins.str] connection_string_prefix: The prefix for the new database proxy connection address can be customized.
        :param pulumi.Input[builtins.str] db_instance_id: Instance ID.
        :param pulumi.Input[builtins.str] db_proxy_connection_string_net_type: The network type of the new database proxy connection address,This resource defaults to Public.
        :param pulumi.Input[builtins.str] db_proxy_endpoint_id: Database proxy connection address ID.
        :param pulumi.Input[builtins.str] db_proxy_new_connect_string_port: The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        if connection_string_prefix is not None:
            pulumi.set(__self__, "connection_string_prefix", connection_string_prefix)
        if db_instance_id is not None:
            pulumi.set(__self__, "db_instance_id", db_instance_id)
        if db_proxy_connection_string_net_type is not None:
            pulumi.set(__self__, "db_proxy_connection_string_net_type", db_proxy_connection_string_net_type)
        if db_proxy_endpoint_id is not None:
            pulumi.set(__self__, "db_proxy_endpoint_id", db_proxy_endpoint_id)
        if db_proxy_new_connect_string_port is not None:
            pulumi.set(__self__, "db_proxy_new_connect_string_port", db_proxy_new_connect_string_port)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The prefix for the new database proxy connection address can be customized.
        """
        return pulumi.get(self, "connection_string_prefix")

    @connection_string_prefix.setter
    def connection_string_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_string_prefix", value)

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @db_instance_id.setter
    def db_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_instance_id", value)

    @property
    @pulumi.getter(name="dbProxyConnectionStringNetType")
    def db_proxy_connection_string_net_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The network type of the new database proxy connection address,This resource defaults to Public.
        """
        return pulumi.get(self, "db_proxy_connection_string_net_type")

    @db_proxy_connection_string_net_type.setter
    def db_proxy_connection_string_net_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_proxy_connection_string_net_type", value)

    @property
    @pulumi.getter(name="dbProxyEndpointId")
    def db_proxy_endpoint_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Database proxy connection address ID.
        """
        return pulumi.get(self, "db_proxy_endpoint_id")

    @db_proxy_endpoint_id.setter
    def db_proxy_endpoint_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_proxy_endpoint_id", value)

    @property
    @pulumi.getter(name="dbProxyNewConnectStringPort")
    def db_proxy_new_connect_string_port(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        return pulumi.get(self, "db_proxy_new_connect_string_port")

    @db_proxy_new_connect_string_port.setter
    def db_proxy_new_connect_string_port(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "db_proxy_new_connect_string_port", value)


@pulumi.type_token("alicloud:rds/dbProxyPublic:DbProxyPublic")
class DbProxyPublic(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_connection_string_net_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_new_connect_string_port: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a RDS database proxy public network address resource.

        For information about Resource AlicloudRdsDBProxyPublic and how to use it, see [What is proxy](https://www.alibabacloud.com/help/en/rds/developer-reference/api-rds-2014-08-15-createdbproxyendpointaddress).

        > **NOTE:** Available since v1.250.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.rds.get_zones(engine="MySQL",
            engine_version="5.6")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=name)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_instance = alicloud.rds.Instance("default",
            engine="MySQL",
            engine_version="5.7",
            instance_type="rds.mysql.c1.large",
            instance_storage=20,
            instance_charge_type="Postpaid",
            instance_name=name,
            vswitch_id=default_switch.id,
            db_instance_storage_type="local_ssd")
        default_read_only_instance = alicloud.rds.ReadOnlyInstance("default",
            zone_id=default_instance.zone_id,
            master_db_instance_id=default_instance.id,
            engine_version=default_instance.engine_version,
            instance_storage=default_instance.instance_storage,
            instance_type=default_instance.instance_type,
            instance_name=f"{name}readonly",
            vswitch_id=default_switch.id)
        default_rds_db_proxy = alicloud.rds.RdsDbProxy("default",
            instance_id=default_instance.id,
            instance_network_type="VPC",
            vpc_id=default_instance.vpc_id,
            vswitch_id=default_instance.vswitch_id,
            db_proxy_instance_num=2,
            db_proxy_connection_prefix="example",
            db_proxy_connect_string_port=3306,
            db_proxy_endpoint_read_write_mode="ReadWrite",
            read_only_instance_max_delay_time=90,
            db_proxy_features="TransactionReadSqlRouteOptimizeStatus:1;ConnectionPersist:1;ReadWriteSpliting:1",
            read_only_instance_distribution_type="Custom",
            read_only_instance_weights=[
                {
                    "instance_id": default_instance.id,
                    "weight": "100",
                },
                {
                    "instance_id": default_read_only_instance.id,
                    "weight": "500",
                },
            ])
        default_db_proxy_public = alicloud.rds.DbProxyPublic("default",
            db_instance_id=default_instance.id,
            db_proxy_endpoint_id=default_rds_db_proxy.db_proxy_endpoint_id,
            connection_string_prefix="exampleabc",
            db_proxy_connection_string_net_type="Public",
            db_proxy_new_connect_string_port="3306")
        ```

        > **NOTE:** Resource `rds.DbProxyPublic` should be created after `rds.RdsDbProxy`, so the `depends_on` statement is necessary.

        ## Import

        RDS Database Proxy Public Network Address can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rds/dbProxyPublic:DbProxyPublic example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] connection_string_prefix: The prefix for the new database proxy connection address can be customized.
        :param pulumi.Input[builtins.str] db_instance_id: Instance ID.
        :param pulumi.Input[builtins.str] db_proxy_connection_string_net_type: The network type of the new database proxy connection address,This resource defaults to Public.
        :param pulumi.Input[builtins.str] db_proxy_endpoint_id: Database proxy connection address ID.
        :param pulumi.Input[builtins.str] db_proxy_new_connect_string_port: The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbProxyPublicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RDS database proxy public network address resource.

        For information about Resource AlicloudRdsDBProxyPublic and how to use it, see [What is proxy](https://www.alibabacloud.com/help/en/rds/developer-reference/api-rds-2014-08-15-createdbproxyendpointaddress).

        > **NOTE:** Available since v1.250.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.rds.get_zones(engine="MySQL",
            engine_version="5.6")
        default_network = alicloud.vpc.Network("default",
            vpc_name=name,
            cidr_block="172.16.0.0/16")
        default_switch = alicloud.vpc.Switch("default",
            vpc_id=default_network.id,
            cidr_block="172.16.0.0/24",
            zone_id=default.zones[0].id,
            vswitch_name=name)
        default_security_group = alicloud.ecs.SecurityGroup("default",
            name=name,
            vpc_id=default_network.id)
        default_instance = alicloud.rds.Instance("default",
            engine="MySQL",
            engine_version="5.7",
            instance_type="rds.mysql.c1.large",
            instance_storage=20,
            instance_charge_type="Postpaid",
            instance_name=name,
            vswitch_id=default_switch.id,
            db_instance_storage_type="local_ssd")
        default_read_only_instance = alicloud.rds.ReadOnlyInstance("default",
            zone_id=default_instance.zone_id,
            master_db_instance_id=default_instance.id,
            engine_version=default_instance.engine_version,
            instance_storage=default_instance.instance_storage,
            instance_type=default_instance.instance_type,
            instance_name=f"{name}readonly",
            vswitch_id=default_switch.id)
        default_rds_db_proxy = alicloud.rds.RdsDbProxy("default",
            instance_id=default_instance.id,
            instance_network_type="VPC",
            vpc_id=default_instance.vpc_id,
            vswitch_id=default_instance.vswitch_id,
            db_proxy_instance_num=2,
            db_proxy_connection_prefix="example",
            db_proxy_connect_string_port=3306,
            db_proxy_endpoint_read_write_mode="ReadWrite",
            read_only_instance_max_delay_time=90,
            db_proxy_features="TransactionReadSqlRouteOptimizeStatus:1;ConnectionPersist:1;ReadWriteSpliting:1",
            read_only_instance_distribution_type="Custom",
            read_only_instance_weights=[
                {
                    "instance_id": default_instance.id,
                    "weight": "100",
                },
                {
                    "instance_id": default_read_only_instance.id,
                    "weight": "500",
                },
            ])
        default_db_proxy_public = alicloud.rds.DbProxyPublic("default",
            db_instance_id=default_instance.id,
            db_proxy_endpoint_id=default_rds_db_proxy.db_proxy_endpoint_id,
            connection_string_prefix="exampleabc",
            db_proxy_connection_string_net_type="Public",
            db_proxy_new_connect_string_port="3306")
        ```

        > **NOTE:** Resource `rds.DbProxyPublic` should be created after `rds.RdsDbProxy`, so the `depends_on` statement is necessary.

        ## Import

        RDS Database Proxy Public Network Address can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rds/dbProxyPublic:DbProxyPublic example <id>
        ```

        :param str resource_name: The name of the resource.
        :param DbProxyPublicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbProxyPublicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_connection_string_net_type: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
                 db_proxy_new_connect_string_port: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbProxyPublicArgs.__new__(DbProxyPublicArgs)

            if connection_string_prefix is None and not opts.urn:
                raise TypeError("Missing required property 'connection_string_prefix'")
            __props__.__dict__["connection_string_prefix"] = connection_string_prefix
            if db_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_instance_id'")
            __props__.__dict__["db_instance_id"] = db_instance_id
            if db_proxy_connection_string_net_type is None and not opts.urn:
                raise TypeError("Missing required property 'db_proxy_connection_string_net_type'")
            __props__.__dict__["db_proxy_connection_string_net_type"] = db_proxy_connection_string_net_type
            if db_proxy_endpoint_id is None and not opts.urn:
                raise TypeError("Missing required property 'db_proxy_endpoint_id'")
            __props__.__dict__["db_proxy_endpoint_id"] = db_proxy_endpoint_id
            __props__.__dict__["db_proxy_new_connect_string_port"] = db_proxy_new_connect_string_port
        super(DbProxyPublic, __self__).__init__(
            'alicloud:rds/dbProxyPublic:DbProxyPublic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connection_string_prefix: Optional[pulumi.Input[builtins.str]] = None,
            db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            db_proxy_connection_string_net_type: Optional[pulumi.Input[builtins.str]] = None,
            db_proxy_endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
            db_proxy_new_connect_string_port: Optional[pulumi.Input[builtins.str]] = None) -> 'DbProxyPublic':
        """
        Get an existing DbProxyPublic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] connection_string_prefix: The prefix for the new database proxy connection address can be customized.
        :param pulumi.Input[builtins.str] db_instance_id: Instance ID.
        :param pulumi.Input[builtins.str] db_proxy_connection_string_net_type: The network type of the new database proxy connection address,This resource defaults to Public.
        :param pulumi.Input[builtins.str] db_proxy_endpoint_id: Database proxy connection address ID.
        :param pulumi.Input[builtins.str] db_proxy_new_connect_string_port: The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbProxyPublicState.__new__(_DbProxyPublicState)

        __props__.__dict__["connection_string_prefix"] = connection_string_prefix
        __props__.__dict__["db_instance_id"] = db_instance_id
        __props__.__dict__["db_proxy_connection_string_net_type"] = db_proxy_connection_string_net_type
        __props__.__dict__["db_proxy_endpoint_id"] = db_proxy_endpoint_id
        __props__.__dict__["db_proxy_new_connect_string_port"] = db_proxy_new_connect_string_port
        return DbProxyPublic(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectionStringPrefix")
    def connection_string_prefix(self) -> pulumi.Output[builtins.str]:
        """
        The prefix for the new database proxy connection address can be customized.
        """
        return pulumi.get(self, "connection_string_prefix")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        Instance ID.
        """
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter(name="dbProxyConnectionStringNetType")
    def db_proxy_connection_string_net_type(self) -> pulumi.Output[builtins.str]:
        """
        The network type of the new database proxy connection address,This resource defaults to Public.
        """
        return pulumi.get(self, "db_proxy_connection_string_net_type")

    @property
    @pulumi.getter(name="dbProxyEndpointId")
    def db_proxy_endpoint_id(self) -> pulumi.Output[builtins.str]:
        """
        Database proxy connection address ID.
        """
        return pulumi.get(self, "db_proxy_endpoint_id")

    @property
    @pulumi.getter(name="dbProxyNewConnectStringPort")
    def db_proxy_new_connect_string_port(self) -> pulumi.Output[builtins.str]:
        """
        The port for the new database proxy connection address is 3306 by default for MySQL and 5432 by default for PostgreSQL, which can be customized.
        """
        return pulumi.get(self, "db_proxy_new_connect_string_port")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSslVpnServersResult',
    'AwaitableGetSslVpnServersResult',
    'get_ssl_vpn_servers',
    'get_ssl_vpn_servers_output',
]

@pulumi.output_type
class GetSslVpnServersResult:
    """
    A collection of values returned by getSslVpnServers.
    """
    def __init__(__self__, id=None, ids=None, name_regex=None, names=None, output_file=None, servers=None, vpn_gateway_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if servers and not isinstance(servers, list):
            raise TypeError("Expected argument 'servers' to be a list")
        pulumi.set(__self__, "servers", servers)
        if vpn_gateway_id and not isinstance(vpn_gateway_id, str):
            raise TypeError("Expected argument 'vpn_gateway_id' to be a str")
        pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of SSL-VPN server IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of SSL-VPN server names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def servers(self) -> Sequence['outputs.GetSslVpnServersServerResult']:
        """
        A list of SSL-VPN servers. Each element contains the following attributes:
        """
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[builtins.str]:
        """
        The ID of the VPN gateway instance.
        """
        return pulumi.get(self, "vpn_gateway_id")


class AwaitableGetSslVpnServersResult(GetSslVpnServersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSslVpnServersResult(
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            servers=self.servers,
            vpn_gateway_id=self.vpn_gateway_id)


def get_ssl_vpn_servers(ids: Optional[Sequence[builtins.str]] = None,
                        name_regex: Optional[builtins.str] = None,
                        output_file: Optional[builtins.str] = None,
                        vpn_gateway_id: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSslVpnServersResult:
    """
    The SSL-VPN servers data source lists lots of SSL-VPN servers resource information owned by an Alicloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    foo = alicloud.vpc.get_ssl_vpn_servers(ids=["fake-server-id"],
        vpn_gateway_id="fake-vpn-id",
        output_file="/tmp/sslserver",
        name_regex="^foo")
    ```


    :param Sequence[builtins.str] ids: IDs of the SSL-VPN servers.
    :param builtins.str name_regex: A regex string of SSL-VPN server name.
    :param builtins.str output_file: Save the result to the file.
    :param builtins.str vpn_gateway_id: Use the VPN gateway ID as the search key.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['vpnGatewayId'] = vpn_gateway_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpc/getSslVpnServers:getSslVpnServers', __args__, opts=opts, typ=GetSslVpnServersResult).value

    return AwaitableGetSslVpnServersResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        servers=pulumi.get(__ret__, 'servers'),
        vpn_gateway_id=pulumi.get(__ret__, 'vpn_gateway_id'))
def get_ssl_vpn_servers_output(ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               vpn_gateway_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSslVpnServersResult]:
    """
    The SSL-VPN servers data source lists lots of SSL-VPN servers resource information owned by an Alicloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    foo = alicloud.vpc.get_ssl_vpn_servers(ids=["fake-server-id"],
        vpn_gateway_id="fake-vpn-id",
        output_file="/tmp/sslserver",
        name_regex="^foo")
    ```


    :param Sequence[builtins.str] ids: IDs of the SSL-VPN servers.
    :param builtins.str name_regex: A regex string of SSL-VPN server name.
    :param builtins.str output_file: Save the result to the file.
    :param builtins.str vpn_gateway_id: Use the VPN gateway ID as the search key.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['vpnGatewayId'] = vpn_gateway_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpc/getSslVpnServers:getSslVpnServers', __args__, opts=opts, typ=GetSslVpnServersResult)
    return __ret__.apply(lambda __response__: GetSslVpnServersResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        servers=pulumi.get(__response__, 'servers'),
        vpn_gateway_id=pulumi.get(__response__, 'vpn_gateway_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CustomDeploymentSetArgs', 'CustomDeploymentSet']

@pulumi.input_type
class CustomDeploymentSetArgs:
    def __init__(__self__, *,
                 custom_deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 on_unable_to_redeploy_failed_instance: Optional[pulumi.Input[builtins.str]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a CustomDeploymentSet resource.
        :param pulumi.Input[builtins.str] custom_deployment_set_name: The name of the resource
        :param pulumi.Input[builtins.str] description: Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        :param pulumi.Input[builtins.int] group_count: Set the number of groups for the deployment set group high availability policy. Value range: 1~7.
               
               Default value: 3
               
               > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        :param pulumi.Input[builtins.str] on_unable_to_redeploy_failed_instance: After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
               - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
               - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.
               
               Default value: CancelMembershipAndStart.
        :param pulumi.Input[builtins.str] strategy: Deployment strategy. Value range:
               - `Availability`: High Availability policy.
               - `AvailabilityGroup`: the high availability policy of the deployment set group.
               - `LowLatency`: Network low latency policy.
               
               Default value: Availability.
        """
        if custom_deployment_set_name is not None:
            pulumi.set(__self__, "custom_deployment_set_name", custom_deployment_set_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_count is not None:
            pulumi.set(__self__, "group_count", group_count)
        if on_unable_to_redeploy_failed_instance is not None:
            pulumi.set(__self__, "on_unable_to_redeploy_failed_instance", on_unable_to_redeploy_failed_instance)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter(name="customDeploymentSetName")
    def custom_deployment_set_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "custom_deployment_set_name")

    @custom_deployment_set_name.setter
    def custom_deployment_set_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_deployment_set_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Set the number of groups for the deployment set group high availability policy. Value range: 1~7.

        Default value: 3

        > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        """
        return pulumi.get(self, "group_count")

    @group_count.setter
    def group_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_count", value)

    @property
    @pulumi.getter(name="onUnableToRedeployFailedInstance")
    def on_unable_to_redeploy_failed_instance(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
        - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
        - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.

        Default value: CancelMembershipAndStart.
        """
        return pulumi.get(self, "on_unable_to_redeploy_failed_instance")

    @on_unable_to_redeploy_failed_instance.setter
    def on_unable_to_redeploy_failed_instance(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "on_unable_to_redeploy_failed_instance", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Deployment strategy. Value range:
        - `Availability`: High Availability policy.
        - `AvailabilityGroup`: the high availability policy of the deployment set group.
        - `LowLatency`: Network low latency policy.

        Default value: Availability.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "strategy", value)


@pulumi.input_type
class _CustomDeploymentSetState:
    def __init__(__self__, *,
                 custom_deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 on_unable_to_redeploy_failed_instance: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomDeploymentSet resources.
        :param pulumi.Input[builtins.str] custom_deployment_set_name: The name of the resource
        :param pulumi.Input[builtins.str] description: Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        :param pulumi.Input[builtins.int] group_count: Set the number of groups for the deployment set group high availability policy. Value range: 1~7.
               
               Default value: 3
               
               > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        :param pulumi.Input[builtins.str] on_unable_to_redeploy_failed_instance: After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
               - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
               - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.
               
               Default value: CancelMembershipAndStart.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[builtins.str] strategy: Deployment strategy. Value range:
               - `Availability`: High Availability policy.
               - `AvailabilityGroup`: the high availability policy of the deployment set group.
               - `LowLatency`: Network low latency policy.
               
               Default value: Availability.
        """
        if custom_deployment_set_name is not None:
            pulumi.set(__self__, "custom_deployment_set_name", custom_deployment_set_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_count is not None:
            pulumi.set(__self__, "group_count", group_count)
        if on_unable_to_redeploy_failed_instance is not None:
            pulumi.set(__self__, "on_unable_to_redeploy_failed_instance", on_unable_to_redeploy_failed_instance)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if strategy is not None:
            pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter(name="customDeploymentSetName")
    def custom_deployment_set_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "custom_deployment_set_name")

    @custom_deployment_set_name.setter
    def custom_deployment_set_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_deployment_set_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Set the number of groups for the deployment set group high availability policy. Value range: 1~7.

        Default value: 3

        > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        """
        return pulumi.get(self, "group_count")

    @group_count.setter
    def group_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "group_count", value)

    @property
    @pulumi.getter(name="onUnableToRedeployFailedInstance")
    def on_unable_to_redeploy_failed_instance(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
        - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
        - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.

        Default value: CancelMembershipAndStart.
        """
        return pulumi.get(self, "on_unable_to_redeploy_failed_instance")

    @on_unable_to_redeploy_failed_instance.setter
    def on_unable_to_redeploy_failed_instance(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "on_unable_to_redeploy_failed_instance", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Deployment strategy. Value range:
        - `Availability`: High Availability policy.
        - `AvailabilityGroup`: the high availability policy of the deployment set group.
        - `LowLatency`: Network low latency policy.

        Default value: Availability.
        """
        return pulumi.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "strategy", value)


@pulumi.type_token("alicloud:rds/customDeploymentSet:CustomDeploymentSet")
class CustomDeploymentSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 on_unable_to_redeploy_failed_instance: Optional[pulumi.Input[builtins.str]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a RDS Custom Deployment Set resource.

        Custom Deployment set.

        For information about RDS Custom Deployment Set and how to use it, see [What is Custom Deployment Set](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.235.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.rds.CustomDeploymentSet("default",
            on_unable_to_redeploy_failed_instance="CancelMembershipAndStart",
            custom_deployment_set_name=name,
            description="2024:11:19 1010:1111:0808",
            group_count=3,
            strategy="Availability")
        ```

        ## Import

        RDS Custom Deployment Set can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rds/customDeploymentSet:CustomDeploymentSet example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_deployment_set_name: The name of the resource
        :param pulumi.Input[builtins.str] description: Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        :param pulumi.Input[builtins.int] group_count: Set the number of groups for the deployment set group high availability policy. Value range: 1~7.
               
               Default value: 3
               
               > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        :param pulumi.Input[builtins.str] on_unable_to_redeploy_failed_instance: After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
               - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
               - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.
               
               Default value: CancelMembershipAndStart.
        :param pulumi.Input[builtins.str] strategy: Deployment strategy. Value range:
               - `Availability`: High Availability policy.
               - `AvailabilityGroup`: the high availability policy of the deployment set group.
               - `LowLatency`: Network low latency policy.
               
               Default value: Availability.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[CustomDeploymentSetArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RDS Custom Deployment Set resource.

        Custom Deployment set.

        For information about RDS Custom Deployment Set and how to use it, see [What is Custom Deployment Set](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.235.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.rds.CustomDeploymentSet("default",
            on_unable_to_redeploy_failed_instance="CancelMembershipAndStart",
            custom_deployment_set_name=name,
            description="2024:11:19 1010:1111:0808",
            group_count=3,
            strategy="Availability")
        ```

        ## Import

        RDS Custom Deployment Set can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:rds/customDeploymentSet:CustomDeploymentSet example <id>
        ```

        :param str resource_name: The name of the resource.
        :param CustomDeploymentSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomDeploymentSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 group_count: Optional[pulumi.Input[builtins.int]] = None,
                 on_unable_to_redeploy_failed_instance: Optional[pulumi.Input[builtins.str]] = None,
                 strategy: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomDeploymentSetArgs.__new__(CustomDeploymentSetArgs)

            __props__.__dict__["custom_deployment_set_name"] = custom_deployment_set_name
            __props__.__dict__["description"] = description
            __props__.__dict__["group_count"] = group_count
            __props__.__dict__["on_unable_to_redeploy_failed_instance"] = on_unable_to_redeploy_failed_instance
            __props__.__dict__["strategy"] = strategy
            __props__.__dict__["status"] = None
        super(CustomDeploymentSet, __self__).__init__(
            'alicloud:rds/customDeploymentSet:CustomDeploymentSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            custom_deployment_set_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            group_count: Optional[pulumi.Input[builtins.int]] = None,
            on_unable_to_redeploy_failed_instance: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            strategy: Optional[pulumi.Input[builtins.str]] = None) -> 'CustomDeploymentSet':
        """
        Get an existing CustomDeploymentSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_deployment_set_name: The name of the resource
        :param pulumi.Input[builtins.str] description: Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        :param pulumi.Input[builtins.int] group_count: Set the number of groups for the deployment set group high availability policy. Value range: 1~7.
               
               Default value: 3
               
               > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        :param pulumi.Input[builtins.str] on_unable_to_redeploy_failed_instance: After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
               - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
               - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.
               
               Default value: CancelMembershipAndStart.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[builtins.str] strategy: Deployment strategy. Value range:
               - `Availability`: High Availability policy.
               - `AvailabilityGroup`: the high availability policy of the deployment set group.
               - `LowLatency`: Network low latency policy.
               
               Default value: Availability.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomDeploymentSetState.__new__(_CustomDeploymentSetState)

        __props__.__dict__["custom_deployment_set_name"] = custom_deployment_set_name
        __props__.__dict__["description"] = description
        __props__.__dict__["group_count"] = group_count
        __props__.__dict__["on_unable_to_redeploy_failed_instance"] = on_unable_to_redeploy_failed_instance
        __props__.__dict__["status"] = status
        __props__.__dict__["strategy"] = strategy
        return CustomDeploymentSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="customDeploymentSetName")
    def custom_deployment_set_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the resource
        """
        return pulumi.get(self, "custom_deployment_set_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Deployment set description information. It must be 2 to 256 characters in length and cannot start with http:// or https.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="groupCount")
    def group_count(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Set the number of groups for the deployment set group high availability policy. Value range: 1~7.

        Default value: 3

        > **NOTE:**  This parameter takes effect only when 'Strategy = AvailabilityGroup.
        """
        return pulumi.get(self, "group_count")

    @property
    @pulumi.getter(name="onUnableToRedeployFailedInstance")
    def on_unable_to_redeploy_failed_instance(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        After the instance in the deployment set is down and migrated, there is no emergency solution for the scattered instance inventory. Value range:
        - `CancelMembershipAndStart`: removes the instance from the deployment set and starts the instance immediately after the instance is down and migrated.
        - `KeepStopped`: The deployment set of the instance is maintained. The instance remains in the stopped state.

        Default value: CancelMembershipAndStart.
        """
        return pulumi.get(self, "on_unable_to_redeploy_failed_instance")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def strategy(self) -> pulumi.Output[builtins.str]:
        """
        Deployment strategy. Value range:
        - `Availability`: High Availability policy.
        - `AvailabilityGroup`: the high availability policy of the deployment set group.
        - `LowLatency`: Network low latency policy.

        Default value: Availability.
        """
        return pulumi.get(self, "strategy")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBasicAccelerateIpEndpointRelationsResult',
    'AwaitableGetBasicAccelerateIpEndpointRelationsResult',
    'get_basic_accelerate_ip_endpoint_relations',
    'get_basic_accelerate_ip_endpoint_relations_output',
]

@pulumi.output_type
class GetBasicAccelerateIpEndpointRelationsResult:
    """
    A collection of values returned by getBasicAccelerateIpEndpointRelations.
    """
    def __init__(__self__, accelerate_ip_id=None, accelerator_id=None, endpoint_id=None, id=None, ids=None, output_file=None, relations=None, status=None):
        if accelerate_ip_id and not isinstance(accelerate_ip_id, str):
            raise TypeError("Expected argument 'accelerate_ip_id' to be a str")
        pulumi.set(__self__, "accelerate_ip_id", accelerate_ip_id)
        if accelerator_id and not isinstance(accelerator_id, str):
            raise TypeError("Expected argument 'accelerator_id' to be a str")
        pulumi.set(__self__, "accelerator_id", accelerator_id)
        if endpoint_id and not isinstance(endpoint_id, str):
            raise TypeError("Expected argument 'endpoint_id' to be a str")
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if relations and not isinstance(relations, list):
            raise TypeError("Expected argument 'relations' to be a list")
        pulumi.set(__self__, "relations", relations)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="accelerateIpId")
    def accelerate_ip_id(self) -> Optional[builtins.str]:
        """
        The ID of the Basic Accelerate IP.
        """
        return pulumi.get(self, "accelerate_ip_id")

    @property
    @pulumi.getter(name="acceleratorId")
    def accelerator_id(self) -> builtins.str:
        """
        The ID of the Global Accelerator Basic Accelerator instance.
        """
        return pulumi.get(self, "accelerator_id")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[builtins.str]:
        """
        The ID of the Basic Endpoint.
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def relations(self) -> Sequence['outputs.GetBasicAccelerateIpEndpointRelationsRelationResult']:
        """
        A list of Global Accelerator Basic Accelerate Ip Endpoint Relations. Each element contains the following attributes:
        """
        return pulumi.get(self, "relations")

    @property
    @pulumi.getter
    def status(self) -> Optional[builtins.str]:
        """
        The status of the Basic Accelerate Ip Endpoint Relation.
        """
        return pulumi.get(self, "status")


class AwaitableGetBasicAccelerateIpEndpointRelationsResult(GetBasicAccelerateIpEndpointRelationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBasicAccelerateIpEndpointRelationsResult(
            accelerate_ip_id=self.accelerate_ip_id,
            accelerator_id=self.accelerator_id,
            endpoint_id=self.endpoint_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            relations=self.relations,
            status=self.status)


def get_basic_accelerate_ip_endpoint_relations(accelerate_ip_id: Optional[builtins.str] = None,
                                               accelerator_id: Optional[builtins.str] = None,
                                               endpoint_id: Optional[builtins.str] = None,
                                               ids: Optional[Sequence[builtins.str]] = None,
                                               output_file: Optional[builtins.str] = None,
                                               status: Optional[builtins.str] = None,
                                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBasicAccelerateIpEndpointRelationsResult:
    """
    This data source provides the Global Accelerator (GA) Basic Accelerate Ip Endpoint Relations of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.194.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ga.get_basic_accelerate_ip_endpoint_relations(ids=["example_id"],
        accelerator_id="example_id")
    pulumi.export("gaBasicAccelerateIpEndpointRelationsId1", ids.relations[0].id)
    ```


    :param builtins.str accelerate_ip_id: The ID of the Basic Accelerate IP.
    :param builtins.str accelerator_id: The ID of the Global Accelerator Basic Accelerator instance.
    :param builtins.str endpoint_id: The ID of the Basic Endpoint.
    :param Sequence[builtins.str] ids: A list of Global Accelerator Basic Accelerate Ip Endpoint Relations IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str status: The status of the Global Accelerator Basic Accelerate Ip Endpoint Relation. Valid Value: `active`.
    """
    __args__ = dict()
    __args__['accelerateIpId'] = accelerate_ip_id
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointId'] = endpoint_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ga/getBasicAccelerateIpEndpointRelations:getBasicAccelerateIpEndpointRelations', __args__, opts=opts, typ=GetBasicAccelerateIpEndpointRelationsResult).value

    return AwaitableGetBasicAccelerateIpEndpointRelationsResult(
        accelerate_ip_id=pulumi.get(__ret__, 'accelerate_ip_id'),
        accelerator_id=pulumi.get(__ret__, 'accelerator_id'),
        endpoint_id=pulumi.get(__ret__, 'endpoint_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        relations=pulumi.get(__ret__, 'relations'),
        status=pulumi.get(__ret__, 'status'))
def get_basic_accelerate_ip_endpoint_relations_output(accelerate_ip_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                      accelerator_id: Optional[pulumi.Input[builtins.str]] = None,
                                                      endpoint_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                      ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                                                      output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                      status: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBasicAccelerateIpEndpointRelationsResult]:
    """
    This data source provides the Global Accelerator (GA) Basic Accelerate Ip Endpoint Relations of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.194.0.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ga.get_basic_accelerate_ip_endpoint_relations(ids=["example_id"],
        accelerator_id="example_id")
    pulumi.export("gaBasicAccelerateIpEndpointRelationsId1", ids.relations[0].id)
    ```


    :param builtins.str accelerate_ip_id: The ID of the Basic Accelerate IP.
    :param builtins.str accelerator_id: The ID of the Global Accelerator Basic Accelerator instance.
    :param builtins.str endpoint_id: The ID of the Basic Endpoint.
    :param Sequence[builtins.str] ids: A list of Global Accelerator Basic Accelerate Ip Endpoint Relations IDs.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str status: The status of the Global Accelerator Basic Accelerate Ip Endpoint Relation. Valid Value: `active`.
    """
    __args__ = dict()
    __args__['accelerateIpId'] = accelerate_ip_id
    __args__['acceleratorId'] = accelerator_id
    __args__['endpointId'] = endpoint_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:ga/getBasicAccelerateIpEndpointRelations:getBasicAccelerateIpEndpointRelations', __args__, opts=opts, typ=GetBasicAccelerateIpEndpointRelationsResult)
    return __ret__.apply(lambda __response__: GetBasicAccelerateIpEndpointRelationsResult(
        accelerate_ip_id=pulumi.get(__response__, 'accelerate_ip_id'),
        accelerator_id=pulumi.get(__response__, 'accelerator_id'),
        endpoint_id=pulumi.get(__response__, 'endpoint_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        relations=pulumi.get(__response__, 'relations'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBucketsResult',
    'AwaitableGetBucketsResult',
    'get_buckets',
    'get_buckets_output',
]

@pulumi.output_type
class GetBucketsResult:
    """
    A collection of values returned by getBuckets.
    """
    def __init__(__self__, buckets=None, id=None, name_regex=None, names=None, output_file=None):
        if buckets and not isinstance(buckets, list):
            raise TypeError("Expected argument 'buckets' to be a list")
        pulumi.set(__self__, "buckets", buckets)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter
    def buckets(self) -> Sequence['outputs.GetBucketsBucketResult']:
        """
        A list of buckets. Each element contains the following attributes:
        """
        return pulumi.get(self, "buckets")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        """
        A list of bucket names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")


class AwaitableGetBucketsResult(GetBucketsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBucketsResult(
            buckets=self.buckets,
            id=self.id,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file)


def get_buckets(name_regex: Optional[builtins.str] = None,
                output_file: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBucketsResult:
    """
    This data source provides the OSS buckets of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.17.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    default = random.index.Integer("default",
        max=99999,
        min=10000)
    bucket = alicloud.oss.Bucket("bucket", bucket=f"oss-tf-example-{default['result']}")
    oss_buckets_ds = alicloud.oss.get_buckets_output(name_regex=bucket.bucket)
    pulumi.export("firstOssBucketName", oss_buckets_ds.buckets[0].name)
    ```


    :param builtins.str name_regex: A regex string to filter results by bucket name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:oss/getBuckets:getBuckets', __args__, opts=opts, typ=GetBucketsResult).value

    return AwaitableGetBucketsResult(
        buckets=pulumi.get(__ret__, 'buckets'),
        id=pulumi.get(__ret__, 'id'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_buckets_output(name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                       output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBucketsResult]:
    """
    This data source provides the OSS buckets of the current Alibaba Cloud user.

    > **NOTE:** Available since v1.17.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud
    import pulumi_random as random

    default = random.index.Integer("default",
        max=99999,
        min=10000)
    bucket = alicloud.oss.Bucket("bucket", bucket=f"oss-tf-example-{default['result']}")
    oss_buckets_ds = alicloud.oss.get_buckets_output(name_regex=bucket.bucket)
    pulumi.export("firstOssBucketName", oss_buckets_ds.buckets[0].name)
    ```


    :param builtins.str name_regex: A regex string to filter results by bucket name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:oss/getBuckets:getBuckets', __args__, opts=opts, typ=GetBucketsResult)
    return __ret__.apply(lambda __response__: GetBucketsResult(
        buckets=pulumi.get(__response__, 'buckets'),
        id=pulumi.get(__response__, 'id'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file')))
